///set more off
///log using SSDISimulationAnalysis.log, text replace
clear all
capture net install tsspell
capture net install outreg2
set scheme s2mono

// DEFINE WORKING DIRECTORY HERE
cd "C:/Users/...." // for pc
cd "~/Dropbox/" // for mac

/// SSDI do file
capture import excel "SSDI.2.5.18.xlsx", sheet("sessiondata") firstrow

drop if WorkerSkill==.

label var LaborMarketCondition "Bad Labor Market Treatment (1=No New Medium Skill Jobs)"
label var VotingCondition "Players Vote on Benefit Levels Treatment (1=Yes)"
label var Worked "Worked in Period (1=Yes)"
label var Injured "Injured in Period (1=Yes)"
label var WorkerSkill "Worker Skill Level (1=Low, 2=Medium, 3=High)"
label var Benefits "Amount of Disability Benefits Earned in Period"
label var Wage "Amount of Wage Earned in Period"
label var DisabilityPlayers "Number of Players on Disability"
label var WorkingPlayers "Number of Players Working"
label var Vote "Vote to Change Benefit Levels (-1=Decrease, 0=Unchanged, 1=Increase)"

gen PeriodSquared=(Period^2)/100 
label var PeriodSquared "Period Squared / 100"

//////// START : CODE TO CALCULATE PROB OF SEEING INJURED/HEALTHY OF OTHER DISABLED PARTICIPANTS IN SOCIAL FEEDBACK //////////
///calculate IPWs: probability of seeing someone healthy conditional on seeing someone on dis

gen on_disab = (BenefitsReceived != 0)					// flag =1 if subject (in session-period) is on disability
egen num_disab = sum(on_disab), by(Session Period)		// by session-period, sum number of subjects on disability
egen num_disab_injured = sum(Injured), by(Session Period) // by session-period, sum number of disabled people who are injured
gen num_disab_healthy = num_disab - num_disab_injured	// by session-period, sum number of disabled people who are healthy

// initialize variables: probability seeing someone is injured/healthy conditional on that person being disabled
gen pr_i_if_disab = .
gen pr_h_if_disab = .

// calculate (i.e., replace missing value) if and only if at the session period level, (#injured|disabled) and (#healthy|disabled) are both not zero
// first create adjusted denominator, subtract off 1 from the denominator if you are disabled (you cant see yourself)
// if you are injured and on disability, subtract off 1 from numerator that measures # injured people
// if you are healthy and on disability, subtract off 1 from numerator that measures # healthy people
// otherwise (i.e., if you are not on disability), do not subtract off from numerator or from denominator

gen prob_see_healthydisab = (num_disab_healthy - 1*((Injured == 0 & Worked == 0))) / (num_disab - on_disab)

gen adj_denom = num_disab
replace adj_denom = num_disab - 1 if on_disab == 1 
 
replace pr_i_if_disab = (num_disab_injured - 1) / adj_denom if (Injured == 1 & on_disab == 1 & num_disab_injured != 0 & num_disab_healthy != 0)
replace pr_i_if_disab = num_disab_injured / adj_denom if (num_disab_injured != 0 & num_disab_healthy != 0)

replace pr_h_if_disab = num_disab_healthy / adj_denom if (num_disab_injured != 0 & num_disab_healthy != 0)
replace pr_h_if_disab = (num_disab_healthy - 1) / adj_denom if (Injured == 0 & on_disab == 1 & num_disab_injured != 0 & num_disab_healthy != 0)

// now define ipw

gen ipw = .

replace ipw = 1 / pr_i_if_disab if ObservedInjured == 1
replace ipw = 1 / pr_h_if_disab if ObservedInjured == 0

replace ipw = . if pr_i_if_disab == 1 & pr_h_if_disab == 0
replace ipw = . if pr_i_if_disab == 0 & pr_h_if_disab == 1

//check IPWs
/*
preserve
sort Session Period
list Session Period PlayerID ObservedInjured pr_h_if_disab pr_i_if_disab ipw if pr_h_if_disab != .
restore
*/

//Label variables
label var on_disab "Subject is on disability (sess-per-subj level)"
label var num_disab "Number on disability (session-period level)"
label var num_disab_injured "Number on disability who are injured (session-period level)"
label var num_disab_healthy "Number on disability who are healthy (session-period level)"
label var pr_i_if_disab "Prob seeing other is injured | other is disabled (sess-per-subj level)"
label var pr_h_if_disab "Prob seeing other is healthy | other is disabled (sess-per-subj level)"
label var ipw  "IPW: 1/Prob see observed feedback about other disabled particip (Sess-per-subj)"
//////// END : CODE TO CALCULATE PROB OF SEEING INJURED/HEALTHY OF OTHER DISABLED PARTICIPANTS IN SOCIAL FEEDBACK //////////

xtset Participant Period
gen RecoveredInThisPeriod=(Injured == 0 & l1.Injured==1 )

///create dichotomous variable for seeing a healthy working player
gen SawHealthyDisability = (ObservedInjured == 0)
label var SawHealthyDisability "Observed a Healthy Worker Collecting Disability"
tab SawHealthyDisability

///create variable for staying on disability when healthy
gen HealthyOnDisability = (Injured == 0 & Worked == 0)
label var HealthyOnDisability "Healthy but Receiving Disability in Period (1=Yes)"
tab HealthyOnDisability

//crosstab of healthy on disability by voting condition
tab HealthyOnDisability VotingCondition if Injured ==0

///create trichotomous labor market variable
gen MarketChange = 1+ (1* LaborMarketCondition == 1) + 2*(Period > 40)
label var MarketChange "Labor Market Status (1=Pre Bad Market, 2=Bad Market, 3=Post Bad Market)"

gen BadLaborMarket= MarketChange==2
label var BadLaborMarket "Bad Labor Market (1=No Medium Skill Jobs)"
gen PostBadLaborMarket = MarketChange==3 
label var PostBadLaborMarket "Post Bad Labor Market (1=Yes)"

///check if players took SSDI in the bad labor market condition
tab HealthyOnDisability LaborMarketCondition if Injured ==0
tab HealthyOnDisability LaborMarketCondition if Injured ==0 & l1.Injured==1, col

gen MediumSkill_BadMarket=LaborMarketCondition*(WorkerSkill==2)
label var MediumSkill_BadMarket "Medium Skill Worker x Bad Labor Market"
gen MediumSkill_PostBadMarket=(MarketChange==3)*(WorkerSkill==2)
label var MediumSkill_PostBadMarket "Medium Skill Worker x Post Bad Labor Market"

///for the voting condition, fix where the change in benefits occurs from the period the vote happened to the period the benefit level took place
gen HighBenefits = l.HighBenefitLevel
replace HighBenefits = 12 if HighBenefits == .
gen MediumBenefits = l.MediumBenefitLevel
replace MediumBenefits = 8 if MediumBenefits == .
label var MediumBenefits "Disability Benefits for Medium Skill Worker"
gen LowBenefits = l.LowBenefitLevel
replace LowBenefits = 6 if LowBenefits == .

gen MediumSkill_SawHealthy = (WorkerSkill==2)*SawHealthyDisability
label var MediumSkill_SawHealthy "Medium Skill Worker x Saw Healthy Collecting Disability"
gen MediumSkill_TotalDisability = (WorkerSkill==2)*DisabilityPlayers
label var MediumSkill_TotalDisability "Medium Skill Worker x Number of Players on Disability"

replace Vote = . if Vote == 99999
gen VotedToReduce = (Vote == -1) if Vote~=.
label var VotedToReduce "Voted to Reduce Benefits (1=Yes)"
egen sdvote=sd(VotedToReduce), by(Participant)

gen SawHealthyCount = SawHealthyDisability + l1.SawHealthyDisability + l2.SawHealthyDisability + l3.SawHealthyDisability + l4.SawHealthyDisability
label var SawHealthyCount "Number of times in last 5 periods saw healthy person on disability"

//generate when medium skill workers were exposed to the bad market
gen BadMarketExperience = 0 if WorkerSkill == 2 & VotingCondition != 0
replace BadMarketExperience = 1 if WorkerSkill == 2 & Injured == 0 & l.Injured == 1 & Period > 20 & Period < 41
by Participant: egen NumberOfBadMarket = total(BadMarketExperience) if WorkerSkill == 2 & VotingCondition != 0 
by Participant (Period), sort: gen FirstBadMarketExperience = sum(BadMarketExperience) == 1 if VotingCondition != 0 & WorkerSkill == 2
bysort Participant: gen drop=sum(FirstBadMarket)
replace FirstBadMarket = . if drop > 1
drop drop

gen InitialClaim = 0
replace InitialClaim = 1 if l.Injured == 1 & Injured == 0
replace InitialClaim = . if Worked == 1|Injured == 1
///should give number of original spells on disability
tab InitialClaim LaborMarketCondition if VotingCondition == 0

gen StayOnDisability = 0
replace StayOnDisability = 1 if Injured == 0 & l.Worked == 0
replace StayOnDisability = . if Worked == 1
//should give number who stay on disability
tab StayOnDisability LaborMarketCondition if VotingCondition == 0

gen AfterFirstDisability = StayOnDisability if InitialClaim != 1

* log using PaperLog.txt, replace text

//***************************** Tables and Figures for Paper start here *****************************

///Experiment 1///

//Simple description of rates of being healthy but not working/etc.

tab Injured if VotingCondition == 0

tab HealthyOnDisability if VotingCondition == 0
tab HealthyOnDisability if VotingCondition == 0 & Injured==0

tab RecoveredInThisPeriod if VotingCondition == 0

tab HealthyOnDisability if VotingCondition == 0 & RecoveredInThisPeriod ==1

tab HealthyOnDisability WorkerSkill if VotingCondition == 0 & RecoveredInThisPeriod ==1, col

tab HealthyOnDisability MarketChange if VotingCondition == 0 & RecoveredInThisPeriod ==1, col
bysort WorkerSkill: tab HealthyOnDisability MarketChange if VotingCondition == 0 & RecoveredInThisPeriod ==1, col

//Table 1: Effect of Bad Labor Market on Healthy People staying on Disability

	//A note on motivation: The idea here is to show in an environment in which there is no indignity for working a lower skill job, people still choose to not work when they have
	//become accustomed to working at a higher wage job that disappears (medium skill)
	//This validates claims from the economics literature that disability substitutes for feasible work
	//Additionally, it sets us up to understand its political implications

	//Model 1: no controls regression of HealthyOnDisability on MarketChange
	xtreg HealthyOnDisability BadLaborMarket PostBadLaborMarket if Injured == 0 & VotingCondition == 0, fe
	outreg2 using Table2.tex, replace tex(frag) dec(3) label nonotes ///
		ctitle(Healthy but,Receiving,Disability in,Period (1=Yes),,Conditional on,Worker Being,Healthy) ///
		addtext(Player Fixed Effects?, Y) ///
		addnote("***p<0.01, **p<0.05, *p<0.1. Standard errors in parentheses.")
		
	//Model 2: regression of HealthyOnDisability on MarketChange and Wo rker Skill given injured last round and now healthy
	xtreg HealthyOnDisability BadLaborMarket PostBadLaborMarket if RecoveredInThisPeriod==1 & VotingCondition == 0, fe
	outreg2 using Table2.tex, append tex(frag) dec(3) label nonotes ///
		addtext(Player Fixed Effects?, Y) ///
		ctitle(Healthy but,Receiving,Disability in,Period (1=Yes),,Conditional on Worker,Becoming Healthy,This Period)
		
	//Model 3: Partitioning effect by worker skill.
	xtreg   HealthyOnDisability BadLaborMarket PostBadLaborMarket MediumSkill_BadMarket MediumSkill_PostBadMarket if RecoveredInThisPeriod==1 & VotingCondition == 0, fe
	outreg2 using Table2.tex, append tex(frag) dec(3) label nonotes ///
		addtext(Player Fixed Effects?, Y) ///
		ctitle(Healthy but,Receiving,Disability in,Period (1=Yes),,Conditional on Worker,Becoming Healthy,This Period)
	

	
///Experiment 2///
//Figure 1: Aggregate benefit levels by condition
	gen NamedSession = ""
	replace NamedSession = "1" if Session == 140202018
	replace NamedSession = "2" if Session == 150172018
	replace NamedSession = "3" if Session == 160222018
	replace NamedSession = "1" if Session == 140242018
	replace NamedSession = "2" if Session == 160242018
	replace NamedSession = "3" if Session == 11132018
	gen BudgetConstraint=.
	replace BudgetConstraint=0 if VotingCondition==1
	replace BudgetConstraint=1 if VotingCondition==2
	label var BudgetConstraint "Benefits Costly (1=Yes, 0=Free Lunch)"
	label define blabel 0 "Free Lunch" 1 "Budget Constraint"
	label values BudgetConstraint blabel
	twoway (line MediumBenefits Period if NamedSession == "1", sort) (line MediumBenefits Period if NamedSession == "2", sort) (line MediumBenefits Period if NamedSession == "3", sort) if VotingCondition != 0 , ytitle("Disability Benefits If Last Job Was Medium Skill" ) ylabel(5(1)11) by(BudgetConstraint, legend(off) note("Each line is a separate session. 3 sessions in each panel.")) name(Figure1, replace)
	graph export Figure1.pdf, replace
	
// Effect of Voting Condition on Voting Behavior

	//For the text, discuss this cross tab, which is conditional on being able to increase or decrease benefits
	tab Vote BudgetConstraint if (MediumBenefits != 5 & MediumBenefits != 11), chi2 col
	tab VotedToReduce BudgetConstraint if (MediumBenefits != 5 & MediumBenefits != 11), chi2 col

	//Reporting similar figure in footnote, but not conditional on benefit levels
	tab Vote BudgetConstraint, chi2 col
	
	/// APPENDIX TABLE 1 (TRICHOTOMOUS VS BINARY DV)
	* Simple regressions
	regress Vote BudgetConstraint i.Period if (MediumBenefits != 5 & MediumBenefits != 11), robust
	outreg2 using AppendixTable1.tex, replace tex(frag) dec(3) label nonotes ///
		ctitle(Vote to Change,Benefit Levels,"(-1=Decrease",0=No Change,"1=Increase)") ///
		addnote("***p<0.01, **p<0.05, *p<0.1. Robust standard errors in parentheses. Sample restricted to voting conditions when possible to increase or decrease benefits.") 
		
	regress VotedToReduce BudgetConstraint i.Period if (MediumBenefits != 5 & MediumBenefits != 11), robust
	outreg2 using AppendixTable1.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(Vote to Reduce,Benefit Levels,"(1=Yes","0=No)") 

		
	/// APPENDIX TABLE 2 (BY CURRENT LEVEL OF BENEFITS)
	* Look only at benefit levels where there are votes under both conditions
	preserve
		keep if (MediumBenefits != 5 & MediumBenefits != 11)
		bysort MediumBenefits: egen sdvoter=sd(BudgetConstraint)
		drop if sdvoter==. | sdvoter==0 | Vote==.
		local first=1
		levelsof MediumBenefits, local(lvls)
		foreach lname of local lvls {
			regress Vote BudgetConstraint i.Period if MediumBenefits==`lname', robust
			if ( `first'==1 ) {
				outreg2 using AppendixTable2.tex, replace tex(frag) dec(3) label nonotes ///
					ctitle("","Vote (-1/0/1)",,Medium,"Benefits=`lname'") ///
					addnote("***p<0.01, **p<0.05, *p<0.1. Robust standard errors in parentheses.")
				local first=0
			}
			else {
				outreg2 using AppendixTable2.tex, append tex(frag) dec(3) label nonotes ///
					ctitle("","Vote (-1/0/1)",,Medium,"Benefits=`lname'") 
			}
			
			regress VotedToReduce BudgetConstraint i.Period if MediumBenefits==`lname', robust
			outreg2 using AppendixTable2.tex, append tex(frag) dec(3) label nonotes ///
					ctitle("","Voted to","Reduce (1=Yes)",,Medium,"Benefits=`lname'")
		}
	restore

			

///Figure 2: How low and high skill workers voted over time, plotted against probability of seeing someone healthy on disability
	twoway (scatter prob_see_healthydisab Period if WorkerSkill==1 | WorkerSkill==3) (lpoly VotedToReduce Period if WorkerSkill==1 | WorkerSkill==3,  bwidth(.5)), xline(20 40) by(BudgetConstraint, note("")) legend(order(1 "Probability saw healthy person on disability" 2 "Voted to reduce benefits")) name(Figure2, replace)
	graph export Figure2.pdf, replace
	
///Appendix Figure 1: SAME AS FIGURE 2 BUT FOR MEDIUM SKILL WORKERS
	twoway (scatter prob_see_healthydisab Period if WorkerSkill==2) (lpoly VotedToReduce Period if WorkerSkill==2,  bwidth(.5)), xline(20 40) by(BudgetConstraint, note("")) legend(order(1 "Probability saw healthy person on disability" 2 "Voted to reduce benefits")) name(FigureAppendixMediumSkillVote, replace)
	graph export AppendixFigure1.pdf, replace

///Some basic analysis of the voting game, using the instrument of the bad labor market to estimate effects on healthy workers being on disability and voting
	sort Participant Period
	

/// TABLE 3 
	* Labor market effects
	xtreg HealthyOnDisability BadLaborMarket PostBadLaborMarket if RecoveredInThisPeriod==1 & (VotingCondition == 1 | VotingCondition==2), fe i(Participant) robust
	outreg2 using Table3.tex, replace tex(frag) dec(3) label nonotes ///
		ctitle("Stay on disability (1=Yes) in period recovered from injury") /// 
		addtext(Player Fixed Effects?, Y) ///
		addnote("***p<0.01, **p<0.05, *p<0.1. Robust standard errors in parentheses.")
		
	xtreg HealthyOnDisability BadLaborMarket PostBadLaborMarket i.MediumBenefits if RecoveredInThisPeriod==1 & (VotingCondition == 1 | VotingCondition==2), fe i(Participant) robust
	outreg2 using Table3.tex, append tex(frag) dec(3) label nonotes ///
		addtext(Player Fixed Effects?, Y) ///
		ctitle("Stay on disability (1=Yes) in period recovered from injury")
	
	xtreg HealthyOnDisability BadLaborMarket PostBadLaborMarket MediumSkill_BadMarket MediumSkill_PostBadMarket if RecoveredInThisPeriod==1 & (VotingCondition == 1 | VotingCondition==2), fe i(Participant) robust
	outreg2 using Table3.tex, append tex(frag) dec(3) label nonotes ///
		addtext(Player Fixed Effects?, Y) ///
		ctitle("Stay on disability (1=Yes) in period recovered from injury")
		
	xtreg HealthyOnDisability BadLaborMarket PostBadLaborMarket MediumSkill_BadMarket MediumSkill_PostBadMarket i.MediumBenefits if RecoveredInThisPeriod==1 & (VotingCondition == 1 | VotingCondition==2), fe i(Participant) robust
	outreg2 using Table3.tex, append tex(frag) dec(3) label nonotes ///
		addtext(Player Fixed Effects?, Y) ///
		ctitle("Stay on disability (1=Yes) in period recovered from injury")
	
/// APPENDIX TABLE 3 (same as Table 3 but for high and low skill workers

tab WorkerSkill, m
tab LaborMarketCondition, m

gen LowSkill = (WorkerSkill==1)
gen HighSkill = (WorkerSkill==3)

gen LowSkill_BadMarket=LaborMarketCondition*(WorkerSkill==1)
label var LowSkill_BadMarket "Low Skill Worker x Bad Labor Market"
gen LowSkill_PostBadMarket=(MarketChange==3)*(WorkerSkill==1)
label var LowSkill_PostBadMarket "Low Skill Worker x Post Bad Labor Market"

gen HighSkill_BadMarket=LaborMarketCondition*(WorkerSkill==3)
label var HighSkill_BadMarket "High Skill Worker x Bad Labor Market"
gen HighSkill_PostBadMarket=(MarketChange==3)*(WorkerSkill==3)
label var HighSkill_PostBadMarket "High Skill Worker x Post Bad Labor Market"
		
	xtreg HealthyOnDisability BadLaborMarket PostBadLaborMarket LowSkill_BadMarket LowSkill_PostBadMarket HighSkill_BadMarket HighSkill_PostBadMarket if RecoveredInThisPeriod==1 & (VotingCondition == 1 | VotingCondition==2), fe i(Participant) robust
	outreg2 using AppendixTable3.tex, replace tex(frag) dec(3) label nonotes ///
		addtext(Player Fixed Effects?, Y) ///
		ctitle("Stay on disability (1=Yes) in period recovered from injury") ///
		addnote("***p<0.01, **p<0.05, *p<0.1. Robust standard errors in parentheses.")
		
	xtreg HealthyOnDisability BadLaborMarket PostBadLaborMarket LowSkill_BadMarket LowSkill_PostBadMarket HighSkill_BadMarket HighSkill_PostBadMarket i.MediumBenefits if RecoveredInThisPeriod==1 & (VotingCondition == 1 | VotingCondition==2), fe i(Participant) robust
	outreg2 using AppendixTable3.tex, append tex(frag) dec(3) label nonotes ///
		addtext(Player Fixed Effects?, Y) ///
		ctitle("Stay on disability (1=Yes) in period recovered from injury")
		

/// ANALYSES FOR FOOTNOTE 13 - APPENDIX TABLE A4

* Footnote analysis, effect of benefit levels on takeup among medium skill workers in budget constraint condition during bad labor market in first period that they recovered
regress HealthyOnDisability MediumBenefits if WorkerSkill ==2 & BadLaborMarket ==1 & BudgetConstraint ==1 & RecoveredInThisPeriod ==1
	outreg2 using AppendixTable4.tex, replace tex(frag) dec(3) label nonotes ///
		ctitle("Stay on disability (1=Yes) in period recovered from injury") ///
		addnote("***p<0.01, **p<0.05, *p<0.1. Standard errors in parentheses.")

regress HealthyOnDisability MediumBenefits Period PeriodSquared if WorkerSkill ==2 & BadLaborMarket ==1 & BudgetConstraint ==1 & RecoveredInThisPeriod ==1
	outreg2 using AppendixTable4.tex, append tex(frag) dec(3) label nonotes ///
		ctitle("Stay on disability (1=Yes) in period recovered from injury") ///
		addnote("***p<0.01, **p<0.05, *p<0.1. Standard errors in parentheses.")


/// TABLE 4
	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket if (VotingCondition == 1 | VotingCondition==2) & WorkerSkill~=2, fe i(Participant) 	
	outreg2 using Table4.tex, replace tex(frag) dec(3) label nonotes ///
		ctitle(Excluding,Medium Skill,Workers) ///
		addnote("***p<0.01, **p<0.05, *p<0.1. Standard errors in parentheses.")

	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket Injured if (VotingCondition == 1 | VotingCondition==2)  & WorkerSkill~=2, fe i(Participant) 	
	outreg2 using Table4.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(Excluding,Medium Skill,Workers) 

	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket Injured if (VotingCondition == 1 | VotingCondition==2) & (MediumBenefits != 5 )  & WorkerSkill~=2, fe i(Participant) 	
	outreg2 using Table4.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(Excluding Cases,where Benefit,Levels Cannot,Be Decreased) 

	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket Injured MediumBenefits if (VotingCondition == 1 | VotingCondition==2) & (MediumBenefits != 5 )  & WorkerSkill~=2, fe i(Participant) 	
	outreg2 using Table4.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(Excluding Cases,where Benefit,Levels Cannot,Be Decreased) 
		
	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket Injured if (VotingCondition == 1) & (MediumBenefits != 5 )  & WorkerSkill~=2, fe i(Participant) 	
	outreg2 using Table4.tex,  append tex(frag) dec(3) label nonotes ///
		ctitle(Free Lunch,Condition,Excluding Cases,where Benefit,Levels Cannot,Be Decreased) 

	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket Injured if (VotingCondition==2) & (MediumBenefits != 5 )  & WorkerSkill~=2, fe i(Participant) 	
	outreg2 using Table4.tex,  append tex(frag) dec(3) label nonotes ///
		ctitle(Budget Constraint,Condition,Excluding Cases,where Benefit,Levels Cannot,Be Decreased) 

/// APPENDIX TABLE:  Same as Table 4 but with medium skill workers
	*This appendix table includes medium skill workers
	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket if (VotingCondition == 1 | VotingCondition==2), fe 	
	outreg2 using AppendixTable03WithMediumSkill.out, se bracket rdec(3) replace
	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket Injured if (VotingCondition == 1 | VotingCondition==2), fe 	
	outreg2 using AppendixTable03WithMediumSkill.out, se bracket rdec(3) append
	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket Injured if (VotingCondition == 1 | VotingCondition==2) & (MediumBenefits != 5 ), fe 	
	outreg2 using AppendixTable03WithMediumSkill.out, se bracket rdec(3) ctitle("Voted to decrease, Excluding cases where benefit levels cannot be decreased") append
	xtreg VotedToReduce BadLaborMarket PostBadLaborMarket Injured MediumBenefits if (VotingCondition == 1 | VotingCondition==2) & (MediumBenefits != 5 ), fe 	
	outreg2 using AppendixTable03WithMediumSkill.out, se bracket rdec(3) append

/// APPENDIX TABLE 5 (Footnote 15)
* Now, before we go anywhere else, let's look just note that at the individual level in the free-lunch condition there is no effect of seeing a free-rider, so we can ignore that condition here.
gen SawHealthy_FreeLunch=SawHealthyDisability*(1-BudgetConstraint)
label var SawHealthy_FreeLunch "Saw Healthy on Disability x Free Lunch condition"
xtreg VotedToReduce SawHealthyDisability SawHealthy_FreeLunch if (WorkerSkill==1 | WorkerSkill==3), fe i(Participant) 
outreg2 using AppendixTable5.tex, replace tex(frag) dec(3) label nonotes ///
	ctitle(DV: Voted to Reduce,Benefits (1=Yes)) ///
	addtext(Player Fixed Effects?, Y) ///
	addnote("***p<0.01, **p<0.05, *p<0.1. Standard errors in parentheses.")
	
///Table 5: Effect of seeing someone who is healthy on voting to reduce benefits by low and high skill workers


	//Model 1: fixed effect regression
	xtreg VotedToReduce SawHealthyDisability if (WorkerSkill==1 | WorkerSkill==3) & VotingCondition==2, fe i(Participant ) 
	outreg2 using Table5.tex, replace tex(frag) dec(3) label nonotes ///
		ctitle(Low and High,Skilled Workers,in Budget,Constraint,Condition) ///
		addtext(Player Fixed Effects?, Y, Session x Period Fixed Effects?, N) ///
		addnote("***p<0.01, **p<0.05, *p<0.1. Standard errors in parentheses. Sample restricted to low- and high-skill workers in the Budget Constraint (i.e., costly benefits) condition.") 
		
	tab VotedToReduce if e(sample)
	
	xtreg VotedToReduce SawHealthyDisability Injured if (WorkerSkill==1 | WorkerSkill==3) & VotingCondition==2, fe i(Participant ) 
	outreg2 using Table5.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(Low and High,Skilled Workers,in Budget,Constraint,Condition) ///
		addtext(Player Fixed Effects?, Y, Session x Period Fixed Effects?, N)
		
	xtreg VotedToReduce SawHealthyDisability Injured if (WorkerSkill==1 | WorkerSkill==3) & VotingCondition==2 & MediumBenefits~=5, fe i(Participant ) 
	outreg2 using Table5.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(And Excluding Cases,where Benefit,Levels Cannot,Be Reduced) ///
		addtext(Player Fixed Effects?, Y, Session x Period Fixed Effects?, N)

	xtreg VotedToReduce SawHealthyDisability Injured MediumBenefits if (WorkerSkill==1 | WorkerSkill==3) & VotingCondition==2 & MediumBenefits~=5, fe i(Participant ) 
	outreg2 using Table5.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(And Excluding Cases,where Benefit,Levels Cannot,Be Reduced) ///
		addtext(Player Fixed Effects?, Y, Session x Period Fixed Effects?, N)
	
	xtreg VotedToReduce SawHealthyDisability Injured Period PeriodSquared if (WorkerSkill==1 | WorkerSkill==3) & VotingCondition==2 & MediumBenefits~=5, fe i(Participant ) 
	outreg2 using Table5.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(And Excluding Cases,where Benefit,Levels Cannot,Be Reduced) ///
		addtext(Player Fixed Effects?, Y, Session x Period Fixed Effects?, N)

	//Model 5: More complicated treatment variable (in last 5 rounds)
	xtreg VotedToReduce SawHealthyCount Injured if (WorkerSkill==1 | WorkerSkill==3) & VotingCondition==2 & MediumBenefits~=5, fe i(Participant ) 
	outreg2 using Table5.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(And Excluding Cases,where Benefit,Levels Cannot,Be Reduced) ///
		addtext(Player Fixed Effects?, Y, Session x Period Fixed Effects?, N)

	//Model 6: Partitioning Effect into disability uptake  and observing abuse
	xtreg DisabilityPlayers  BadLaborMarket  if (WorkerSkill==1 | WorkerSkill==3) & VotingCondition==2 & MediumBenefits~=5, fe i(Participant ) 

	xtreg VotedToReduce SawHealthyDisability Injured DisabilityPlayers if (WorkerSkill==1 | WorkerSkill==3) & VotingCondition==2 & MediumBenefits~=5, fe i(Participant ) 
	outreg2 using Table5.tex, append tex(frag) dec(3) label nonotes ///
		ctitle(Observing,Versus,Infering,Abuse) ///
		addtext(Player Fixed Effects?, Y, Session x Period Fixed Effects?, N)

	//Code for next few models is to subset to non-medium skill workers not on disability and to created matched pairs in specific periods
	preserve
		egen sessionperiods=group(Session Period)
		* Eliminate cases where benefits cannot be decreased
		drop if MediumBenefits==5
		* Keep only low and high skill people and eliminate healthy people on disability
		drop if WorkerSkill ==2 
		drop if HealthyOnDisability==1
		* Must also be variability in chance of seeing healthy person on disability
		drop if ipw==. | ipw==1 | ipw==0
		count
		bysort sessionperiods : gen R=_N
		drop if R==1
		drop R
	
		//Models 7 and 8: Matched Pairs analysis
		
		*NB, this produces the same result as dummying in the i.sessionperiods
		*xtreg VotedToReduce SawHealthyDisability i.WorkerSkill Injured, fe i(sessionperiods) 
		*outreg using Table04.out, se bracket rdec(3) 3aster ctitle("Voted to decrease, Matched pairs") append

		regress VotedToReduce SawHealthyDisability i.WorkerSkill Injured i.sessionperiods
		outreg2 using Table5.tex, append tex(frag) dec(3) label nonotes ///
			drop(i.sessionperiods) ///
			ctitle(Matched,Pairs,(Unweighted)) ///
			addtext(Player Fixed Effects?, N, Session x Period Fixed Effects?, Y)
		
		tab VotedToReduce if e(sample)
		
		regress VotedToReduce SawHealthyDisability i.WorkerSkill Injured i.sessionperiods [pweight=ipw]
		outreg2 using Table5.tex, append tex(frag) dec(3) label nonotes ///
			drop(i.sessionperiods) ///
			ctitle(Matched,Pairs,(Weighted)) ///
			addtext(Player Fixed Effects?, N, Session x Period Fixed Effects?, Y)
		
		
	restore
	

* log close

